==> xlniuxdata-league-1.0.2-sources.jar: com/xunlei/niux/data/league/vo/NiuxCash.java <==
package com.xunlei.niux.data.league.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

@Table(tableName="niuxcash",pkFieldName="cashNo",pkFieldAssign=true)
public class NiuxCash {
	private String cashNo;
	private String expireDate;
	private Double parValue;
	private String cashStatus;
	private String useTime;
	private String userId;
	private String generateNo;
	private Double minPayMoney;
	private String receiveUserId;
	private String receiveTime;
	@Column(columnName="receiveTime",isWhereColumn=true,operator=Operator.GE)
	private String fromReceiveTime;
	@Column(columnName="receiveTime",isWhereColumn=true,operator=Operator.LE)
	private String toReceiveTime;
	
	private String receiveOrderNo;
	public String getReceiveOrderNo() {
		return receiveOrderNo;
	}
	public void setReceiveOrderNo(String receiveOrderNo) {
		this.receiveOrderNo = receiveOrderNo;
	}
	public String getReceiveUserId() {
		return receiveUserId;
	}
	public void setReceiveUserId(String receiveUserId) {
		this.receiveUserId = receiveUserId;
	}
	public String getReceiveTime() {
		return receiveTime;
	}
	public void setReceiveTime(String receiveTime) {
		this.receiveTime = receiveTime;
	}
	public String getFromReceiveTime() {
		return fromReceiveTime;
	}
	public void setFromReceiveTime(String fromReceiveTime) {
		this.fromReceiveTime = fromReceiveTime;
	}
	public String getToReceiveTime() {
		return toReceiveTime;
	}
	public void setToReceiveTime(String toReceiveTime) {
		this.toReceiveTime = toReceiveTime;
	}
	public Double getMinPayMoney() {
		return minPayMoney;
	}
	public void setMinPayMoney(Double minPayMoney) {
		this.minPayMoney = minPayMoney;
	}
	public String getGenerateNo() {
		return generateNo;
	}
	public void setGenerateNo(String generateNo) {
		this.generateNo = generateNo;
	}
	public String getCashNo() {
		return cashNo;
	}
	public void setCashNo(String cashNo) {
		this.cashNo = cashNo;
	}
	public String getExpireDate() {
		return expireDate;
	}
	public void setExpireDate(String expireDate) {
		this.expireDate = expireDate;
	}
	public Double getParValue() {
		return parValue;
	}
	public void setParValue(Double parValue) {
		this.parValue = parValue;
	}
	public String getCashStatus() {
		return cashStatus;
	}
	public void setCashStatus(String cashStatus) {
		this.cashStatus = cashStatus;
	}
	public String getUseTime() {
		return useTime;
	}
	public void setUseTime(String useTime) {
		this.useTime = useTime;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
}

==> xlniuxdata-league-1.0.5-sources.jar: com/xunlei/niux/data/league/vo/NiuxCash.java <==
package com.xunlei.niux.data.league.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

@Table(tableName="niuxcash",pkFieldName="cashNo",pkFieldAssign=true)
public class NiuxCash {
	private String cashNo;
	private String expireDate;
	private Double parValue;
	private String cashStatus;
	private String useTime;
	private String userId;
	private String generateNo;
	private Double minPayMoney;
	private String receiveUserId;
	private String receiveTime;
	@Column(columnName="receiveTime",isWhereColumn=true,operator=Operator.GE)
	private String fromReceiveTime;
	@Column(columnName="receiveTime",isWhereColumn=true,operator=Operator.LE)
	private String toReceiveTime;
	private String receiveOrderNo;
    private String limitedgameid;

    public String getLimitedgameid() {
        return limitedgameid;
    }

    public void setLimitedgameid(String limitedgameid) {
        this.limitedgameid = limitedgameid;
    }

    public String getReceiveOrderNo() {
		return receiveOrderNo;
	}
	public void setReceiveOrderNo(String receiveOrderNo) {
		this.receiveOrderNo = receiveOrderNo;
	}
	public String getReceiveUserId() {
		return receiveUserId;
	}
	public void setReceiveUserId(String receiveUserId) {
		this.receiveUserId = receiveUserId;
	}
	public String getReceiveTime() {
		return receiveTime;
	}
	public void setReceiveTime(String receiveTime) {
		this.receiveTime = receiveTime;
	}
	public String getFromReceiveTime() {
		return fromReceiveTime;
	}
	public void setFromReceiveTime(String fromReceiveTime) {
		this.fromReceiveTime = fromReceiveTime;
	}
	public String getToReceiveTime() {
		return toReceiveTime;
	}
	public void setToReceiveTime(String toReceiveTime) {
		this.toReceiveTime = toReceiveTime;
	}
	public Double getMinPayMoney() {
		return minPayMoney;
	}
	public void setMinPayMoney(Double minPayMoney) {
		this.minPayMoney = minPayMoney;
	}
	public String getGenerateNo() {
		return generateNo;
	}
	public void setGenerateNo(String generateNo) {
		this.generateNo = generateNo;
	}
	public String getCashNo() {
		return cashNo;
	}
	public void setCashNo(String cashNo) {
		this.cashNo = cashNo;
	}
	public String getExpireDate() {
		return expireDate;
	}
	public void setExpireDate(String expireDate) {
		this.expireDate = expireDate;
	}
	public Double getParValue() {
		return parValue;
	}
	public void setParValue(Double parValue) {
		this.parValue = parValue;
	}
	public String getCashStatus() {
		return cashStatus;
	}
	public void setCashStatus(String cashStatus) {
		this.cashStatus = cashStatus;
	}
	public String getUseTime() {
		return useTime;
	}
	public void setUseTime(String useTime) {
		this.useTime = useTime;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
}
